#
# spec file for package virt-viewer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Enabled for Tumbleweed
%if 0%{?suse_version} >= 1550
%define with_govirt 0
%else
%define with_govirt 0
%endif

Name:           virt-viewer
Summary:        Virtual Machine Viewer
License:        GPL-2.0-or-later
Group:          System/Monitoring
Version:        11.0
Release:        5.4
URL:            http://www.virt-manager.org
Source:         https://releases.pagure.org/virt-viewer/virt-viewer-%{version}.tar.xz
Source1:        https://releases.pagure.org/virt-viewer/virt-viewer-%{version}.tar.xz.asc
Patch1:         001-Update-src-virt-viewer-app.c.patch
Patch2:         002-Use-less-memory.patch
Patch3:         003-Fix-ssh-tunnel-with-non-POSIX-remote-shells.patch
Patch4:         004-Add-support-for-usb-redirect-on-connect-in-vv-files.patch
Patch5:         005-session-vnc-Plug-leak-in-error-path.patch
Patch50:        netcat.patch
Patch51:        virtview-desktop.patch
Patch52:        virtview-dont-show-Domain-0.patch
Patch53:        virtview-fix-build-with-meson-0.61.patch
Patch100:       gcc-warnings-as-errors.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  bash-completion-devel
BuildRequires:  cmake
BuildRequires:  gtk-vnc-devel >= 0.3.8
BuildRequires:  intltool
BuildRequires:  libglade2-devel
%if %{with_govirt}
BuildRequires:  libgovirt-devel
%endif
BuildRequires:  libpixman-1-0-devel
BuildRequires:  libxml2-devel
BuildRequires:  meson
BuildRequires:  spice-gtk-devel
BuildRequires:  vte-devel
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-vnc-2.0)
BuildRequires:  pkgconfig(libvirt) >= 1.2.8
BuildRequires:  pkgconfig(libvirt-glib-1.0) >= 1.2.8
%if %{with_govirt}
BuildRequires:  pkgconfig(rest-0.7)
%endif
# Our Runtime requirements
Requires:       netcat

%description
Virtual Machine Viewer provides a graphical console client for
connecting to virtual machines. It uses the GTK-VNC widget to provide
the display, and libvirt for looking up VNC server details.

%prep
%autosetup -p1

%if ! %{with_govirt}
%define govirt_arg -Dovirt=disabled
%else
%define govirt_arg -Dovirt=enabled
%endif

%build
%meson \
    -Dspice=enabled \
    %{govirt_arg} \
    %{nil}
%meson_build

%install
%meson_install
%{find_lang} %{name}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS
%license COPYING
%dir %{_datadir}/metainfo
%dir %{_datadir}/bash-completion/completions
%{_bindir}/%{name}
%{_bindir}/remote-viewer
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/virt-viewer.1*
%{_mandir}/man1/remote-viewer.1*
%{_datadir}/applications/remote-viewer.desktop
%{_datadir}/mime/packages/virt-viewer-mime.xml
%{_datadir}/bash-completion/completions/virt-viewer
%{_datadir}/metainfo/remote-viewer.appdata.xml

%changelog
* Fri Dec  1 2023 carnold@suse.com
- Upstream bug fixes (bsc#1166289) (jsc#PED-6305)
  001-Update-src-virt-viewer-app.c.patch
  002-Use-less-memory.patch
  003-Fix-ssh-tunnel-with-non-POSIX-remote-shells.patch
  004-Add-support-for-usb-redirect-on-connect-in-vv-files.patch
  005-session-vnc-Plug-leak-in-error-path.patch
* Tue Oct 18 2022 carnold@suse.com
- bsc#203689 - [tw 20220921] remote-viewer fails to start:
  libsoup3 symbols detected.
  virt-viewer.spec
* Wed Oct  5 2022 carnold@suse.com
- Fix build failures in Factory
  gcc-warnings-as-errors.patch
* Wed Feb 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Fix build with meson 0.60 and newer.
  virtview-fix-build-with-meson-0.61.patch
* Tue Nov 30 2021 carnold@suse.com
- Update to 11.0:
  * Minimum libgovirt is now 0.3.7
  * CentOS 7 is no longer a supported build platform
  * Use header bar for oVirt ISO dialog
  * Add change CD button to toolbar for oVirt
  * Support using ISOs in oVirt DATA storage domains
  * Remove clashing -r command line shortcut for ‘resize’ that
    clashed with existing ‘reconnect’ shortcut
  * Support modifier-only hotkeys for cursor release
  * Fix smartcard and USB hotkey configuration regression
  * Add USB device reset hotkey support
  * Fix various mixed up GTK actions for hotkeys
  * Release keyboard grab at same time as mouse grab with SPICE
  * Fix misc compiler warnings with glib > 2.68
  * Fix creation of window when guest uses multiple heads with a
    single QXL video card
  * Updated translations from weblate
  * Avoid warnings from GTK from overly strict minimum desktop
    width/height rules
  * Update window action sensitivity to fix regression causing
    disabled send key menu items
  * Fix mixed up action / menu state when user cancels a quit
    request
  * Ensure auth dialog credential fields are cleared
  * Fix setting os-id when building RPMs
  * Avoid extra hyphen in build ID strings
  * Explicitly disable spice/ovirt features when invoking meson
    for RPM builds
  * Fix uninitialized variable for keymaps
- Dropped patches contained in new tarball
  0001-src-initialize-keymaps-variable.patch
  0002-rpm-explicitly-tell-meson-to-disable-spice-ovirt.patch
  0003-config.h-avoid-extra-hyphen-in-build-ID-value.patch
  0004-config.h-conditionally-define-REMOTE_VIEWER_OS_ID.patch
  0005-Fix-creation-of-window-when-using-single-QXL-card-with-2-heads.patch
  0006-src-avoid-warnings-from-use-of-G_GNUC_FALLTHROUGH.patch
* Mon Oct 11 2021 carnold@suse.com
- Fix broken build in Factory (bsc#1166289)
  0006-src-avoid-warnings-from-use-of-G_GNUC_FALLTHROUGH.patch
* Tue Jul 20 2021 carnold@suse.com
- bsc#1185531 - virt-viewer 10.0 second display handling
  0005-Fix-creation-of-window-when-using-single-QXL-card-with-2-heads.patch
* Tue May 11 2021 carnold@suse.com
- libgovirt doesn't exist on SLE so enable only for Tumbleweed
  virt-viewer.spec
* Tue May  4 2021 carnold@suse.com
- Upstream bug fixes (bsc#1166289)
  0001-src-initialize-keymaps-variable.patch
  0002-rpm-explicitly-tell-meson-to-disable-spice-ovirt.patch
  0003-config.h-avoid-extra-hyphen-in-build-ID-value.patch
  0004-config.h-conditionally-define-REMOTE_VIEWER_OS_ID.patch
* Wed Apr 21 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 10.0:
  * Switch to use Meson for build system instead of autotools
  * Require libvirt >= 1.2.8
  * Redesign UI to use title bar widget instead of menu bar
  * Request use of dark theme by default, if available
  * Don't filter out oVirt DATA storage domains
    for ISO image sharing
  * Add --keymap arg to allow keys to be remapped
  * Display error message if no extension is present
    for screenshot filename
  * Fix misc memory leaks
  * Use nicer error message if not ISOs are available
  * Use more explicit accelerator hint to distinguish
    left and right ctrl/alt keys
  * Report detailed file transfer errors
  * Use standard about diaglog
  * Refresh and improve translations
  * Install appstream data file in preferred location
  * Refresh appstream data file contents
  * Display VM title when listing VMs, if available
  * Display VM description as tooltop, if available
  * Sort VM names when listing
  * Add --shared arg to request a shared session for VNC
  * Disable all accels when not grabbed in kiosk mode
  * Allow num keypad to be used for zoom changes
  * Disable grab sequence in kiosk mode to prevent escape
  * Allow zoom hotkeys to be set on the command line / vv file
  * Display error message if VNC connection fails
  * Fix warnings about atomics with new GLib
  * Remove use of deprecated GTK APIs
  * Document cursor ungrab sequence in man pages
  * Honour Ctrl-C when auth dialog is active
  * Minor UI tweaks to auth dialog
  * Support VM power control actions with VNC
  * Add --cursor arg to control whether a local pointer is
    rendered with VNC
  * Add --auto-resize arg and menu to control whether to
  * resize the remote framebuffer to math local window size
  * Add support for remote framebuffer resize with VNC
  * Handle case sensitivity when parsing accelerator mappings
* Fri May  1 2020 carnold@suse.com
- Update to 9.0:
  - Project moved to https://gitlab.com/virt-viewer/virt-viewer
  - Allow toggling shared clipboard in remote-viewer
  - Fix handling when initial spice connection fails
  - Fix check for govirt library
  - Add bash completion of cli args
  - Improve errors in file transfer dialog
  - Fix ovirt foreign menu storage domains query
  - Prefer TLS certs from oVirt instead of CLI
  - Improve USB device cleanup when Ctrl-C is used
  - Remember monitor mappings across restarts
  - Add a default file extension to screenshots
  - Updated translations
  - Fix misc memory leaks
- Update virtview-desktop.patch
- Drop
  c2dabf07-Fix-a-regression-when-initial-connection-fails.patch
  a13173ae-remote-viewer-fix-free-on-dangling-pointer.patch
  a724dff8-remote-viewer-add-handler-for-SIGINT-signal.patch
  e4bacb8f-remote-viewer-add-a-default-extension-to-screenshot-filenames.patch
* Tue Mar 10 2020 carnold@suse.com
- bsc#1166288 - Enable vte in remote-viewer build to support
  multiple spice displays (eg: qemu-kvm -display spice-app)
  virt-viewer.spec
* Mon Mar  9 2020 carnold@suse.com
- Upstream bug fixes (bsc#1166289)
  c2dabf07-Fix-a-regression-when-initial-connection-fails.patch
  a13173ae-remote-viewer-fix-free-on-dangling-pointer.patch
  a724dff8-remote-viewer-add-handler-for-SIGINT-signal.patch
  e4bacb8f-remote-viewer-add-a-default-extension-to-screenshot-filenames.patch
* Thu Mar 14 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0:
  - Fix warnings with latest GCC versions
  - More strictly filter out non-ISO images in ovirt menu
  - Require libgovirt >= 0.3.3
  - Require librest >= 0.8
  - Support UNIX and TLS URI schemes for spice
  - Fix full screen monitor placement under wayland
  - Fix command line encoding on Windows
  - Ensure VM name is set in window title
  - Support unix-path in .vv files
  - Support text console windows via VTE
  - Add machine power control menu options
  - Record full build env in MSI installer
- update virtview-desktop.patch
* Fri Jul 27 2018 carnold@suse.com
- Update to virt-viewer version 7.0
  virt-viewer-7.0.tar.gz
  - Require spice-gtk >= 0.35
  - Clarify error message when no running VM is found
  - Improve check for libgovirt requirements
  - Support "-" as a URI for input connection file
  - Remove support for spice controller interface
  - Misc man page fixes
  - Lookup win32 translations relative to install dir
  - Position connect window in center not top-left
  - Misc fixes for ovirt foreign menu support
- Drop
  140cb84c-remote-viewer-remove--spice-controller.patch
  bf39970a-virt-viewer.spec.in-fix-build-after-spice-xpi-client-removal.patch
  virtview-fix-configure-after-spice-controller-removal.patch
* Thu Jul  5 2018 carnold@suse.com
- bsc#1100300 - virt-viewer: Build fails because spice-gtk no
  longer has the spice-controller library
  140cb84c-remote-viewer-remove--spice-controller.patch
  bf39970a-virt-viewer.spec.in-fix-build-after-spice-xpi-client-removal.patch
  virtview-fix-configure-after-spice-controller-removal.patch
* Tue Aug 15 2017 carnold@suse.com
- Update to virt-viewer version 6.0
  virt-viewer-6.0.tar.bz2
  - Mention use of ssh-agent in man page
  - Display connection issue warnings in main window
  - Switch to GTask API
  - Add support changing CD ISO with oVirt foreign menu
  - Update various outdated links in README
  - Avoid printing password in debug logs
  - Pass hostname to authentication dialog
  - Fix example URLs in man page
  - Add args to virt-viewer to specify whether to resolve VM based on ID, UUID or name
  - Fix misc runtime warnings
  - Improve support for extracting listening info from XML
  - Enable connecting to SPICE over UNIX socket
  - Fix warnings with newer GCCs
  - Allow controlling zoom level with keypad
  - Don’t close app during seemless migration
  - Don’t show toolbar in kiosk mode
  - Re-show auth dialog in kiosk mode
  - Don’t show error when cancelling auth
  - Change default screenshot name to ‘Screenshot.png’
  - Report errors when saving screenshot
  - Fix build with latest glib-mkenums
- Dropped
  reverse-3d5627d7-for-xen.patch
* Wed Jan 18 2017 carnold@suse.com
- bsc#976796 - Drop duplicate icon entry in desktop file
  virtview-desktop.patch
* Mon Nov 28 2016 carnold@suse.com
- Update to virt-viewer version 5.0
  virt-viewer-5.0.tar.bz2
  - Don’t retry authentication when credentials are provided via vvfile
  - Fix display of guest name in title for VNC
  - Fix detection of domain stop when tunnelling over SSH
  - Fix problem resizing with GTK client side decorations
  - Fix leak on file transfer
  - Only include native spec file in dist to fix rpmbuild -ta
  - Check min required spice-glib version
  - Display errors to user if failing to open UNIX socket
  - Simplify file transfer UI to only display overall progress, rather than full list of files
  - Show list of files which failed to transfer
- Dropped
  35e489d5-fix-display-of-guest-name-in-title-for-vnc.patch
  813c775c-fix-filename-leak-on-transfer-dialog.patch
  a62827d2-close-when-seeing-domain-stop-event.patch
* Fri Aug 19 2016 carnold@suse.com
- bsc#983689 - virt-viewer shows Domain-0 on list of virtual
  machines
  virtview-dont-show-Domain-0.patch
- Upstream bug fix
  813c775c-fix-filename-leak-on-transfer-dialog.patch
* Fri Jul 22 2016 jengelh@inai.de
- Use source URL
- Remove redundant %%clean section
* Thu Jul 14 2016 carnold@suse.com
- bsc#988858 - SLES12-SP2-Beta4 - virt-viewer throws Gtk-WARNING
  even with --quiet switch
- Update to virt-viewer version 4.0
  virt-viewer-4.0.tar.bz2
  35e489d5-fix-display-of-guest-name-in-title-for-vnc.patch
  a62827d2-close-when-seeing-domain-stop-event.patch
  - Drop support for gtk2 builds
  - Require spice-gtk >= 0.31
  - Require glib2 >= 2.38
  - Require gtk3 >= 3.10
  - Require libvirt-glib >= 0.1.8
  - Increase minimum window size fo 320×200 instead of 50×50
  - Remove use of GSLice
  - Don’t show usbredir button if not connected yet
  - Only compute monitor mapping in full screen
  - Don’t ignore usb-filter in spiec vv-file
  - Port to use GtkApplication API
  - Don’t leave window open after connection failure
  - Validate symbols from max glib/gdk versions
  - Don’t use GtkStock
  - Don’t use gtk_widget-modify_{fg,bg} APIs
  - Drop use of built-in eventloop in favour of libvirt-glib
  - Don’t open X display while parsing command line
  - Fix window title
  - Use GResource for building ui files into binary
  - Fix crash with invalid spice monitor mapping
  - Add dialog to show file transfer progress and allow cancelling
  - Remove unused nsis installer support
  - Include adwaita icon theme in msi builds
  - Add more menu mnemonics
  - Fix support for windows consoles to allow I/O redirection
  - Add support for ovirt sso-token in vv-file
  - Fix crash with zooming window while not connected
  - Remove custom auto drawer widget with GtkRevealer
  - Add appdata file for gnome software
  - Misc other bug fixes
  - Refresh translations
- Dropped
  fix-crash-on-zoom-change.patch
  windows-keycombo.patch
  netware-keycombo.patch
* Wed Jun  8 2016 carnold@suse.com
- bsc#982793 - virt-viewer installation create unusable launcher
  virtview-desktop.patch
* Mon Jun  6 2016 carnold@suse.com
- bsc#979735 - Virt-viewer: Changing zoom on disconnected machine
  crashes application
  fix-crash-on-zoom-change.patch
* Tue Jan 12 2016 ohering@suse.de
- Require at least glib2 >= 2.26 in pre-SLE12 builds
* Mon Jan 11 2016 carnold@suse.com
- Update to virt-viewer version 3.1
  virt-viewer-3.1.tar.bz2
  - Last release to support GTK2 for Linux. The next 4.0 release
    will be GTK3 only
  - Don’t add URI scheme / path info to oVirt URIs
  - Require spice-gtk >= 0.30
  - Enable webdav folder sharing with spice
  - Add preferences UI dialog
  - Take –direct into account when checking if guest is reachable
  - Take SPICE proxy into account when connecting to oVirt
    instances
  - Fail gracefully when hostname is not returned by oVirt
  - Don’t show empty foreign menu on secondary displays
  - Avoid accidentally trying to connect to port 0 when oVirt
    doesn’t specify a port number
  - Correctly update geometry when enabling/disabling display heads
  - Avoid accidentally creating extra monitors when using
    configuration file monitor mapping
  - Exit normally when cancelling connect dialog
  - Don’t wait for a guest that we know will never show up
  - Fix crash when using –reconnect with SPICE
  - Avoid zooming out if it would decrease window size below
    minimum required for top menu display
  - Fix crash when disabling last enabled display
  - Honour changes in display position from guest
  - Don’t show error dialog twice for unknown graphics type
  - Allow to cancel oVirt auth without error
  - Set sensitivity of display menu based on whether it is usable
    or not
  - Set sensitivity of tool bar buttons based on whether they are
    usable or not
  - Set guest name reported by VNC
  - Fix crash when using gtk-vnc 0.3.8
  - Fix alt-tab behaviour in choose VM dialog
  - Don’t allow missing display in monitor mapping config
  - Add –with-osid flag to configure to allow specifying the
    operating system build target. The values should be based on
    libosinfo OS short IDs.
  - Ensure windows installer places menu icon for all users not
    just admin. Requires manual uninstall of previous windows
    version
  - Require address in remote viewer connect dialog
  - Automatically retry VNC connection after auth failure
  - Drop GTK2 support for Windows builds
  - Enable keepalives on libvirt conncetion
  - Allow resize of window to arbitrary size
  - Fix thread safety handling event callbacks
  - Avoid deprecation warnings with newer glib
  - Pulled in multiple fixes for event loop from libvirt-glib
  - Fix misc bugs reported by coverity
  - Fix binary ID in MSI installer
  - Stop polling libvirt after reconnecting to libvirt
- Drop old tarball
  virt-viewer-3.0.tar.bz2
* Fri Dec 11 2015 carnold@suse.com
- Update to virt-viewer version 3.0
  virt-viewer-3.0.tar.bz2
  - Last release to support GTK2 for Linux. The next 4.0 release
    will be GTK3 only
  - Don’t add URI scheme / path info to oVirt URIs
  - Require spice-gtk >= 0.30
  - Enable webdav folder sharing with spice
  - Add preferences UI dialog
  - Take –direct into account when checking if guest is reachable
  - Take SPICE proxy into account when connecting to oVirt
    instances
  - Fail gracefully when hostname is not returned by oVirt
  - Don’t show empty foreign menu on secondary displays
  - Avoid accidentally trying to connect to port 0 when oVirt
    doesn’t specify a port number
  - Correctly update geometry when enabling/disabling display heads
  - Avoid accidentally creating extra monitors when using
    configuration file monitor mapping
  - Exit normally when cancelling connect dialog
  - Don’t wait for a guest that we know will never show up
  - Fix crash when using –reconnect with SPICE
  - Avoid zooming out if it would decrease window size below
    minimum required for top menu display
  - Fix crash when disabling last enabled display
  - Honour changes in display position from guest
  - Don’t show error dialog twice for unknown graphics type
  - Allow to cancel oVirt auth without error
  - Set sensitivity of display menu based on whether it is usable
    or not
  - Set sensitivity of tool bar buttons based on whether they are
    usable or not
  - Set guest name reported by VNC
  - Fix crash when using gtk-vnc 0.3.8
  - Fix alt-tab behaviour in choose VM dialog
  - Don’t allow missing display in monitor mapping config
  - Add –with-osid flag to configure to allow specifying the
    operating system build target. The values should be based on
    libosinfo OS short IDs.
  - Ensure windows installer places menu icon for all users not
    just admin. Requires manual uninstall of previous windows
    version
  - Require address in remote viewer connect dialog
  - Automatically retry VNC connection after auth failure
  - Drop GTK2 support for Windows builds
  - Enable keepalives on libvirt conncetion
  - Allow resize of window to arbitrary size
  - Fix thread safety handling event callbacks
  - Avoid deprecation warnings with newer glib
  - Pulled in multiple fixes for event loop from libvirt-glib
  - Fix misc bugs reported by coverity
  - Fix binary ID in MSI installer
  - Stop polling libvirt after reconnecting to libvirt
* Mon Sep 21 2015 carnold@suse.com
- bsc#946816 - virt-viewer: version 2.0 can't connect to Xen VMs
  reverse-3d5627d7-for-xen.patch
* Mon Jan 12 2015 carnold@suse.com
- Update to virt-viewer version 2.0
  virt-viewer-2.0.tar.bz2
  - Fix handling of zoom in/out accelerators
  - Fix warning going in/out of fullscreen
  - Add dialog showing info about the current guest
  - Change format of fullscreen config setting to
    allow for sparse guest displays
  - Write VM name to config file as a comment
  - Never use fallback CA certs when loading vv-file
  - Remove extraneous '/' from oVirt URIs
  - Support oVirt foreign menus
  - Allow using numapad for zoom in/out accelerators
  - Force geometry update when agent connects
  - Fix misc crash bugs
  - Fix misc memory leaks
  - Allow viewing of password entry characters
  - Don't fail when auth dialog is cancelled
  - Only create extra windows on demand
  - Use more sensible default window size
  - Improve docs for URIs and config files
  - Allow cancellation of SPICE auth dialog
  - Use new libvirt API for --attach to avoid SELinux AVC
  - Allow removable of CD images with oVirt connections
  - Show VM choose dialog when oVirt VM name is missing
  - Support usernames request with SASL auth
  - Use socat instead of nc if available
  - Use PNG instead of SVG for icons
  - Support connection to UNIX sockets instead of TCP
  - Honour zoom level from CLI args with VNC
  - Switch to GTK3 instead of GKT2 for Windows builds
  - Ensure dialogs have transient parent set
  - Switch to gstreamer 1.0 instead of 0.10 for Windows builds
  - Avoid accidentally connecting to localhost with VNC/SPICE
  - Use a versioned install directory for Windows builds
- Dropped sources
  virt-viewer-1.0.tar.bz2
  report-error.patch
* Tue Jul 22 2014 carnold@suse.com
- Update to virt-viewer version 1.0
  virt-viewer-1.0.tar.bz2
  - Switched to 2-digit version numbering.
  - Improve error reporting when failing to find
    the GtkBuilder UI files
  - Honour title provided by SPICE server if available
  - Don't hide main window when disconnecting in multi-monitor
    configurations
  - Don't show VNC widget until authentication has completed
  - Fix session handling when re-authenticating
  - Improve docs for --attach flag
  - Ask for credentials for SPICE proxy
  - Fix scaling of windows when resizing
  - Remove 'Automatically resize' menu, leaving the behaviour
    permanently enabled
  - Improve USB icon in full screen toolbar
  - Don't resize guest when changing zoom level
  - Don't create windows at startup if kiosk mode isn't enabled
  - Don't show quit confirmation dialog in kiosk mode
  - Misc typos / fixes in man pages
  - Fix race with metacity window manager in fullscreen mode
  - Avoid accidentally connecting to localhost with --direct flag
  - Use custom log handler to silence debug messages on old glib2
  - Fix tiny windows for secondary displays with gtk2 build
  - Take zoom into account when checkign display limits
  - Fix unshrinkable displays with windows guests
  - Allow  ctrl-[+-] to zoom in fullscreen mode
- Dropped upstream patches and old tarball
  virt-viewer-0.6.0.tar.bz2
  52fa6455-display-warning-if-UI-file-fails.patch
  52fce019-dont-free-session-if-auth-retry.patch
  52fce019-dont-hide-main-window-when-disconnecting.patch
  530b1cfc-german-translation-send-key-fix.patch
  530b66e9-spice-ask-credentials-for-proxy.patch
  53209ab7-fix-scaling-of-window-upon-resize.patch
  53219d1a-silence-message-about-missing-config-file.patch
  5322b75b-dont-show-quit-dialog-in-kiosk-mode.patch
  5322b929-fix-building-with-older-spice-gtk.patch
  538df41a-set-freed-variables-to-null.patch
  5396d3dd-dont-connect-to-localhost-when-using-direct.patch
  53970bee-remove-warning-when-removing-display.patch
  53975d94-fix-tiny-windows-for-secondary-displays-in-gtk2-build.patch
  5398b944-take-zoom-level-into-account-for-display-limits.patch
  5398b971-fix-tiny-window-when-resetting-zoom-factor-in-gtk2-build.patch
  53a8716d-fix-un-shrinkable-displays-on-windows-guests.patch
* Mon Jul  7 2014 carnold@suse.com
- Drop spice-gtk.patch.  It was only needed for systems with
  spice-gtk version < 0.22
* Fri Jul  4 2014 aginies@suse.com
- fix build: remove spice_uuid_to_string definition no more needed with
  the new spice-gtk
* Tue Jul  1 2014 carnold@suse.com
- Upstream bug fixes
  53970bee-remove-warning-when-removing-display.patch
  53975d94-fix-tiny-windows-for-secondary-displays-in-gtk2-build.patch
  5398b944-take-zoom-level-into-account-for-display-limits.patch
  5398b971-fix-tiny-window-when-resetting-zoom-factor-in-gtk2-build.patch
  53a8716d-fix-un-shrinkable-displays-on-windows-guests.patch
* Tue Jul  1 2014 fcrozat@suse.com
- Switch build to gtk3 for SLE12 and openSUSE 13.2.
- Update windows-keycombo.patch and netware-keycombo.patch to build
  with GTK 3.
* Tue Jun 10 2014 carnold@suse.com
- Upstream bug fix
  5396d3dd-dont-connect-to-localhost-when-using-direct.patch
* Wed Jun  4 2014 carnold@suse.com
- Upstream bug fix
  538df41a-set-freed-variables-to-null.patch
* Tue Mar 25 2014 carnold@suse.com
- Drop patch as it causes initial viewer size problems
  52fce019-set-VNC-display-ready-after-VNC-initialized.patch
* Fri Mar 14 2014 carnold@suse.com
- Upstream bug fixes
  530b66e9-spice-ask-credentials-for-proxy.patch
  53209ab7-fix-scaling-of-window-upon-resize.patch
  53219d1a-silence-message-about-missing-config-file.patch
  5322b75b-dont-show-quit-dialog-in-kiosk-mode.patch
  5322b929-fix-building-with-older-spice-gtk.patch
* Thu Feb 27 2014 carnold@suse.com
- Upstream bug fixes
  52fa6455-display-warning-if-UI-file-fails.patch
  52fce019-dont-free-session-if-auth-retry.patch
  52fce019-dont-hide-main-window-when-disconnecting.patch
  52fce019-set-VNC-display-ready-after-VNC-initialized.patch
  530b1cfc-german-translation-send-key-fix.patch
* Mon Jan 27 2014 carnold@suse.com
- Update to virt-viewer version 0.6.0
  * Require govirt 0.3.0
  * Require spice-gtk 0.22
  * Show error dialog if password is wrong
  * Document application/x-virt-viewer file format
  * Remove unused ‘-d’ option from remote-viewer
  * Add a kiosk mode
  * Add menu for sending Ctrl+Alt+Delete
  * Add Ctrl+Alt+End as accelerator for Ctrl+Alt+Delete
  * Send modifiers before the non-modifier key in send key menu
  * Fix GTK warning when disconnecting from VNC due to auth error
  * Make ‘Cancel’ default button in exit dialog
  * Make send key menu accelerators work in fullscreen
  * Remove insecure fetching of oVirt CA cert
  * Build for GTK 3 by default
  * Fix title bar after failed connection
  * Reshow remote-viewer connection dialog upon error
  * Hide all windows upon disconnect
  * Add ability to define custom monitor mapping
  * Ensure all windows obey command line zoom level
  * Add an icon to the desktop file
  * Fix event loop implementation on Win32 platforms
  * Misc other bug fixes
- Allow the use of spice-gtk version 0.21. Drop patch when 0.22
  becomes available.
  spice-gtk.patch
- Renamed netcat.diff to netcat.patch
* Wed Aug 14 2013 carnold@suse.com
- Enable spice support
* Wed Jul 31 2013 carnold@suse.com
- Update to virt-viewer version 0.5.7
  * Many fixes to full screen / window positioning handling
  * Reshow connect dialog if connection fails
  * Misc man page fixes
  * Mark RPM as obsoleting spice-client
  * Set the host subject to fix SSL connections with ovirt
  * Use -H as short variant of –hotkeys
  * Add missing trailing ‘;’ in desktop file
  * Allow TLS only SPICE connections
  * Use dynamic key send menu
  * Enable smartcard shortcuts only when smartcard reader is present
  * Misc other bug fixes
- Drop glade-keycombo.patch
* Mon Jun 10 2013 carnold@suse.com
- Update to virt-viewer version 0.5.6
  * Add ovirt:// support to remote-viewer (needs libgovirt)
  * Many fullscreen and multi-monitor fixes
  * Add a minimum version check in connection file
  * Fix sending key combinations from “Send Key” menu when the key
    names are localized
  * Fix build with older glib and gtk+
  * Fix MSI x64 build
  * Clean-ups (remove browser plugin entirely)
* Tue Mar  5 2013 carnold@suse.com
- Update to virt-viewer version 0.5.5
  * Improve screenshot saving dialog
  * remote-viewer learned to connect with a file of mime type
    application/x-virt-viewer, described in src/virt-viewer-file.c
  * Add a "do not ask me again" dialog checkbox when leaving
  * Add a MSI target, using https://live.gnome.org/msitools
  * Add windows debug helper, useful in Spice controller running
    context
  * Add remote-viewer --title STRING
  * Support for Spice proxy settings added
  * Numerous Spice display and multi-monitor fixes
  * win32, memory, build, and other misc fixes
  * Requires spice-gtk >= 0.16.26
* Wed Jan  2 2013 carnold@novell.com
- Enable virt-viewer to be built for s390x
* Thu Dec  6 2012 carnold@novell.com
- Upstream bug fix
  virtview-git-transport-segv.patch
* Mon Nov 12 2012 carnold@novell.com
- Upstream bug fixes
  virtview-git-ipv6-check.patch
  virtview-git-resize-window.patch
  virtview-git-spice-rounding.patch
  virtview-git-spice-resize-window.patch
  virtview-git-ssh-localhost-connect.patch
* Mon Sep 17 2012 carnold@novell.com
- Update to virt-viewer version 0.5.4
  * Fix host migration with Spice
  * Fix misc memory leaks
  * Fix build with newer glibc and -O0
  * Improve automatic fullscreen Spice configuration
  * Avoid crash when quiting application
  * Rebuild display menu whenever a window is added/removed
  * Number displays starting from 1 instead of 0
  * Add support for handling multiple monitors with Spice
  * Menu display menu insensitive if no displays can be selected
  * Use real binary name in remote-viewer help message
  * Document -f=auto-conf in remote-viewer help
* Tue Aug 14 2012 chris@computersalat.de
- fix build for SLE_11
  * rework virtview-desktop patch
* Thu May 17 2012 carnold@novell.com
- Update to virt-viewer version 0.5.3
  * Add support for raw IPv6 addresses
  * Add a remote-viewer.desktop file and register spice:// handling
  * Add a simple connection dialog to remote-viewer
  * Add remote-viewer --fullscreen=auto-conf option, to update guest monitors configuration to match client
  * Spice controller support for disable-effects, color-depth and usbredir
  * Spice controller interaction fixes
  * Windows version and nsis installer improvements
  * Import newer translations from transifex
  * Misc reference leak / crash bugs fixed
* Tue Apr 24 2012 carnold@novell.com
- Fix failure of viewer to close when guest is terminated
  virtview-git-vnc-close.patch
- Additional upstream fix
  virtview-git-uri-crash.patch
* Wed Mar 21 2012 carnold@novell.com
- Update to virt-viewer version 0.5.2
  * Require libvirt > 0.9.7, spice-gtk > 0.11, spice-protocol >= 0.10.1
  * Import newer translations from transifex
  * remote-viewer learned Spice controller customizable key bindings, smartcard property, and foreign menu
  * Fix Spice crash on re-connection
  * Fix connecting via ssh to a password-protected server
  * Add a sendkey menu in fullscreen mode
  * Add USB device selection in fullscreen mode
  * Misc reference leak / crash bugs fixed
* Fri Feb  3 2012 carnold@novell.com
- Update to virt-viewer version 0.4.2
  * Fix exports of signal functions for GTK UI builder on Windows
  * Avoid crash if xmlParseURI fails
  * Fix inverted test for SSH port that broke tunnelling
  * Don't hardcode port numbers for SSH if not requested by user
  * Fix deadlock in event handling
  * Fix initial zoom level for all windows
  * Fix window title to include domain name
  * Fix hostname used when XML gives a wildcard IP address
  * Fix window title when waiting for domain to appear
  * Fix key shortcust for F9-F12 menus
  * Always ask libvirt for its canonical URI
  * Allow build without GTK-VNC (ie spice only)
  * Require GTK-VNC >= 0.4.3
  * Require SPICE-GTK >= 0.6.0
* Fri Jan  6 2012 carnold@novell.com
- Fix failure to resize viewer.  Noted usually when tunneling via ssh
  virtview-git-emit-resize.patch
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Nov 21 2011 carnold@novell.com
- Always use canonical URI from libvirt connection
  virtview-git-canonical-uri.patch
* Tue Oct 18 2011 carnold@novell.com
- Upstream bug fixes
  virtview-git-fn-key.patch
  virtview-git-window-wait.patch
* Mon Sep 26 2011 carnold@novell.com
- Update to virt-viewer version 0.4.1
  + Remove bogus use of AM_GLIB_GNU_GETTEXT macro to try to facilitate BSD builds
  + Support multiple monitors with SPICE and QXL drivers
  + Don't hardcode SSH port to 22 when tunnelling
  + Require SPICE-GTK >= 0.6
  + Hide menu bar when going fullscreen
  + Support building against GTK2 or GTK3
  + Convert from Glade to GtkBuilder
  + Honour 'listen' attribute from <graphics> XML when connecting
  + Fix reconnection after authentication failure
  + Make --verbose flag actually do something
  + Enable scaling with SPICE to match VNC behaviour
  + Rewrite widget resizing code to (try to) be more reliable
  + Fill extra space outside guest display with black
  + Fix (null) in title bar while not connected
  + Fix multiple memory leaks
  + Fix reconnecting to display with SPICE
* Thu Jul 28 2011 carnold@novell.com
- Fixed error "Using GTK+ 2.x and GTK+ 3 in the same process is
  not supported"
* Tue Jul 12 2011 carnold@novell.com
- Fixed spec file rpmlint warnings for language files.
- Patch cleanup and re-enabled vnc-listen.patch
* Mon Jul 11 2011 carnold@novell.com
- Fix re-connect after authentication failure
  virtview-reconnect-fix.patch
* Tue Jul  5 2011 carnold@novell.com
- Fix "directories not owned by a package:" warnings.
* Thu May 12 2011 carnold@novell.com
- Fix spec file for building with gtk-vnc 2.0
* Mon Apr  4 2011 carnold@novell.com
- Update to virt-viewer version 0.3.1
  + Add support for Spice
  + Add support for spice resize-guest
  + Add support for zoom levels
  + Add a menu for zooming in/out of the virtual desktop.
  + Add a --zoom command line to set the initial zoom level.
  + Support connections over UNIX sockets
* Thu Aug 26 2010 ro@suse.de
- change buildreq to libpixman-1-0-devel
* Thu Apr 29 2010 carnold@novell.com
- Update to virt-viewer 0.2.1
  + Bug fixes
  + Translations
* Thu Feb 11 2010 carnold@novell.com
- bnc#574591 - There is no prompt if I view a inexist guest OS
  using virt-viewer
  report-error.patch
* Fri Dec  4 2009 carnold@novell.com
- Fixed the 'Send Key' menu with all the missing keys for netware and
  windows.
  glade-keycombo.patch
* Mon Nov  9 2009 carnold@novell.com
- bnc#553633 - Update breaks menu access keys in virt-viewer and
  still misses some key sequences.
  This is a SLE10 bug fixed for SLE11.
* Thu Jul 30 2009 carnold@novell.com
- Update to virt-viewer version 0.2.0
  + Switch UI over to use Glade
  + Support graphical dialog for VNC and libvirt authentication
  + Resize window to match VNC desktop size where possible
  + Scale down VNC desktop if it cannot fit in host desktop space
  + Allow user to resize window to arbitrary size, scaling VNC
  + Fix blocking of accelerators
  + Allow automatic reconnect to a VM via --reconnect
  + Use libvirt events to detect when VM changes state
  + Wait for VM to appear if it does not exist
  + Fix plugin build with newer xulrunner
  + Port & build for Mingw32 target
* Tue Jul 28 2009 carnold@novell.com
- bnc#522740 - SLES10SP3 Xen - Unable to install Netware OES2
  6.5SP8 VM
* Tue Jun 16 2009 carnold@novell.com
- bnc#448474 - Patch to enable keys that sends a NetWare server to
  the debugger.
  netware-keycombo.patch
* Fri May  8 2009 carnold@novell.com
- bnc#499560 - Viirt-viewer needs ability to crash dump Windows VMs
  with Ctrl+Scroll+Scroll
  windows-keycombo.patch
* Mon Mar  9 2009 jfehlig@novell.com
- Connect viewer to vnc-listen address specified in domain
  configuration (bnc#436629)
  vnc-listen.patch
* Fri Nov  7 2008 dpmerrill@novell.com
- Changed lib from nc to netcat for ssh connections (bnc#397633)
* Sat Sep 13 2008 carnold@suse.de
- Update to version 0.0.3
- This release addresses a number of minor bugs. It will block
  accelerators when keyboard grab is active. Password characters
  are hidden in text entry field. The domain name is used in the
  title bar. The guest console can be resized using smooth
  hardware accelerated scaling. An experimental firefox plugin was
  added that can be used to access a console from a web browser.
* Tue Aug 19 2008 ro@suse.de
- add exclusivearch for x86 and x86_64 (as buildrequired libvirt)
* Sat Jan 19 2008 dpmerrill@novell.com
- Added new virt-viewer package to sle10-sp2-i386
- (FATE Feature #302140)
